#!/usr/bin/env python3

"""extract a (sharded) list of SWHIDs corresponding to the database dump exported from
Software Heritage, for reproducibility purposes

Depends: zstd

"""

__copyright__ = "Copyright (C) 2020  Stefano Zacchiroli"
__license__ = "GPL-3.0-or-later"

import sys

from subprocess import Popen, PIPE

hex_digits = "0123456789abcdef"
swhid_dest = "commit-ids-{digit}.txt.zst"
swhid_line = "swh:1:rev:{digest}\n"
encoding = "utf8"

pipes = {}
for digit in hex_digits:
    pipes[digit] = Popen(
        ["zstdmt", "-o", swhid_dest.format(digit=digit), "--force", "--quiet", "-"],
        stdin=PIPE,
        encoding=encoding,
    )

for line in sys.stdin:
    digest = line[2:42]
    digit = digest[0]
    pipes[digit].stdin.write(swhid_line.format(digest=digest))

for pipe in pipes.values():
    pipe.communicate()
